==> neo4j-consistency-check-2.3.4-sources.jar: org/neo4j/consistency/checking/labelscan/LabelScanDocumentProcessor.java <==
/*
 * Copyright (c) 2002-2016 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.consistency.checking.labelscan;

import org.neo4j.consistency.checking.full.RecordProcessor;
import org.neo4j.consistency.report.ConsistencyReporter;
import org.neo4j.consistency.store.synthetic.LabelScanDocument;
import org.neo4j.kernel.api.direct.NodeLabelRange;

public class LabelScanDocumentProcessor extends RecordProcessor.Adapter<NodeLabelRange>
{
    private final ConsistencyReporter reporter;
    private final LabelScanCheck labelScanCheck;

    public LabelScanDocumentProcessor( ConsistencyReporter reporter, LabelScanCheck labelScanCheck )
    {
        this.reporter = reporter;
        this.labelScanCheck = labelScanCheck;
    }

    @Override
    public void process( NodeLabelRange nodeLabelRange )
    {
        reporter.forNodeLabelScan( new LabelScanDocument( nodeLabelRange ), labelScanCheck );
    }
}

==> neo4j-consistency-check-3.5.12-sources.jar: org/neo4j/consistency/checking/labelscan/LabelScanDocumentProcessor.java <==
/*
 * Copyright (c) 2002-2019 "Neo4j,"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.consistency.checking.labelscan;

import org.neo4j.consistency.checking.full.RecordProcessor;
import org.neo4j.consistency.report.ConsistencyReporter;
import org.neo4j.consistency.store.synthetic.LabelScanDocument;
import org.neo4j.kernel.api.labelscan.NodeLabelRange;

public class LabelScanDocumentProcessor extends RecordProcessor.Adapter<NodeLabelRange>
{
    private final ConsistencyReporter reporter;
    private final LabelScanCheck labelScanCheck;

    public LabelScanDocumentProcessor( ConsistencyReporter reporter, LabelScanCheck labelScanCheck )
    {
        this.reporter = reporter;
        this.labelScanCheck = labelScanCheck;
    }

    @Override
    public void process( NodeLabelRange nodeLabelRange )
    {
        reporter.forNodeLabelScan( new LabelScanDocument( nodeLabelRange ), labelScanCheck );
    }
}
